==> cx88-1.1.0.tar.gz: cx88-1.1.0/client/drivers/pchdtv_hd5500.h <==
/*-
 * Copyright 2007 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __PCHDTV_HD5500_H__
#define __PCHDTV_HD5500_H__

#include <stdlib.h>
#include <unistd.h>
#include "lgh064f.h"
#include "lg3303.h"
#include "cx88_mpeg_driver.h"
#include "cx88_analog_driver.h"

namespace cx88_mpeg_driver_factory
{

   class pchdtv_hd5500
      : public cx88_mpeg_driver
   {
      public:
         
         pchdtv_hd5500(
            cx88_xml_config &cx88conf,
            tuner_config &tunerconf,
            const char *devnode,
            capvec &captures,
            int &error)
            : cx88_mpeg_driver(cx88conf, tunerconf, devnode, captures, error)
         {}
         
         virtual ~pchdtv_hd5500(void) {}
   
      protected:
         
         virtual int create_i2c_drivers(void)
         {
            int error = 0;
            cx88_common_gpio gpio;
            gpio.in_write_mask = 0x1;
            gpio.in_read_mask = 0x0;
            gpio.inout_gpio = 0x0;
            if ((error = ioctl(m_fd, CX88_COMMON_GPIO, &gpio)) != 0)
            {
               CX88ERR << "Error issuing GPIO ioctl: " << strerror(errno) << endl;
               return error;
            }
            usleep(100000);
            gpio.in_write_mask = 0x1;
            gpio.in_read_mask = 0x0;
            gpio.inout_gpio = 0x1;
            if ((error = (ioctl(m_fd, CX88_COMMON_GPIO, &gpio)) != 0))
            {
               CX88ERR << "Error issuing GPIO ioctl: " << strerror(errno) << endl;
               return error;  
            }
            usleep(200000);
            m_i2c_devs[0].driver = new lgh064f(m_tunerconf, *(m_i2c_devs[0].dev));
            m_i2c_devs[1].driver = new lg3303(m_tunerconf, *(m_i2c_devs[1].dev), DVB_IFC_NEG_POL, DVB_INPUT_SERIAL, error);
            if ((m_i2c_devs[0].driver == NULL) || (m_i2c_devs[1].driver == NULL))
            {
               CX88ERR << "Error initializing tuner/demodulator driver for pcHDTV HD-5500" << endl;
               return ENOMEM;
            }
            return error;
         }
         
         virtual void destroy_i2c_drivers(void)
         {
            delete m_i2c_devs[1].driver;
            delete m_i2c_devs[0].driver;  
         }
         
         virtual int create_i2c_devices(cx88_common_i2c_config &config)
         {
            config.in_i2c_addrs[0] = 0x61;
            config.in_i2c_addrs[1] = 0x59;
            config.in_num_i2c_devices = 2;
            return 0;
         }
         
         virtual int set_capture_options(cx88_mpeg_capture &capture)
         {
            capture.in_options = CX88_MPEG_SERIAL_INPUT | CX88_MPEG_BYTEWIDE_SOP;
            return 0;
         }
   };
};

namespace cx88_analog_driver_factory
{
   class pchdtv_hd5500
      : public cx88_analog_driver
   {
      public:
         
         pchdtv_hd5500(
            cx88_xml_config &cx88conf,
            tuner_config &tunerconf,
            const char *devnode,
            capvec &captures,
            cx88_analog_mode mode,
            cx88_analog_driver *slave,
            cx88_analog_driver *pip_driver,
            int &error)
            : cx88_analog_driver(cx88conf, tunerconf, devnode, captures, mode, slave, pip_driver, error)
         {}
         
         virtual ~pchdtv_hd5500(void) {}
         
      protected:
         
         virtual int create_i2c_drivers(void)
         {
            m_i2c_devs[0].driver = new lgh064f(m_tunerconf, *(m_i2c_devs[0].dev));
            if (m_i2c_devs[0].driver == NULL)
            {
               CX88ERR << "Error initializing tuner driver for pcHDTV HD-3000" << endl;
               return ENOMEM;
            }
            return 0;
         }
         
         virtual void destroy_i2c_drivers(void)
         {
            delete m_i2c_devs[0].driver;  
         }
         
         virtual int create_i2c_devices(cx88_common_i2c_config &config)
         {
            config.in_i2c_addrs[0] = 0x61;
            config.in_num_i2c_devices = 1;
            return 0;
         }
   
   };
   
};

#endif

==> cx88-1.2.1.tar.gz: cx88-1.2.1/client/drivers/pchdtv_hd5500.h <==
/*-
 * Copyright 2007 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __PCHDTV_HD5500_H__
#define __PCHDTV_HD5500_H__

#include <stdlib.h>
#include <unistd.h>
#include "lgh064f.h"
#include "lg3303.h"
#include "cx88_mpeg_driver.h"
#include "cx88_analog_driver.h"

namespace cx88_mpeg_driver_factory
{

   class pchdtv_hd5500
      : public cx88_mpeg_driver
   {
      public:
         
         pchdtv_hd5500(
            cx88_xml_config &cx88conf,
            tuner_config &tunerconf,
            const char *devnode,
            capvec &captures,
            int &error)
            : cx88_mpeg_driver(cx88conf, tunerconf, devnode, captures, error)
         {}
         
         virtual ~pchdtv_hd5500(void) {}
   
      protected:
         
         virtual int create_i2c_drivers(void)
         {
            int error = 0;
            cx88_common_gpio gpio;
            gpio.in_write_mask = 0x1;
            gpio.in_read_mask = 0x0;
            gpio.inout_gpio = 0x0;
            if ((error = ioctl(m_fd, CX88_COMMON_GPIO, &gpio)) != 0)
            {
               CX88ERR << "Error issuing GPIO ioctl: " << strerror(errno) << endl;
               return error;
            }
            usleep(100000);
            gpio.in_write_mask = 0x1;
            gpio.in_read_mask = 0x0;
            gpio.inout_gpio = 0x1;
            if ((error = (ioctl(m_fd, CX88_COMMON_GPIO, &gpio)) != 0))
            {
               CX88ERR << "Error issuing GPIO ioctl: " << strerror(errno) << endl;
               return error;  
            }
            usleep(200000);
            m_i2c_devs[0].driver = new lgh064f(m_tunerconf, *(m_i2c_devs[0].dev));
            m_i2c_devs[1].driver = new lg3303(m_tunerconf, *(m_i2c_devs[1].dev), DVB_IFC_NEG_POL, DVB_INPUT_SERIAL, error);
            if ((m_i2c_devs[0].driver == NULL) || (m_i2c_devs[1].driver == NULL))
            {
               CX88ERR << "Error initializing tuner/demodulator driver for pcHDTV HD-5500" << endl;
               return ENOMEM;
            }
            return error;
         }
         
         virtual void destroy_i2c_drivers(void)
         {
            delete m_i2c_devs[1].driver;
            delete m_i2c_devs[0].driver;  
         }
         
         virtual int create_i2c_devices(void)
         {
            m_i2c_devs[0].conf.in_addr = 0x61;
            m_i2c_devs[1].conf.in_addr = 0x59;
            return 0;
         }
         
         virtual int set_capture_options(cx88_mpeg_capture &capture)
         {
            capture.in_options = CX88_MPEG_SERIAL_INPUT | CX88_MPEG_BYTEWIDE_SOP;
            return 0;
         }
   };
};

namespace cx88_analog_driver_factory
{
   class pchdtv_hd5500
      : public cx88_analog_driver
   {
      public:
         
         pchdtv_hd5500(
            cx88_xml_config &cx88conf,
            tuner_config &tunerconf,
            const char *devnode,
            capvec &captures,
            cx88_analog_mode mode,
            cx88_analog_driver *slave,
            cx88_analog_driver *pip_driver,
            int &error)
            : cx88_analog_driver(cx88conf, tunerconf, devnode, captures, mode, slave, pip_driver, error)
         {}
         
         virtual ~pchdtv_hd5500(void) {}
         
      protected:
         
         virtual int create_i2c_drivers(void)
         {
            m_i2c_devs[0].driver = new lgh064f(m_tunerconf, *(m_i2c_devs[0].dev));
            if (m_i2c_devs[0].driver == NULL)
            {
               CX88ERR << "Error initializing tuner driver for pcHDTV HD-3000" << endl;
               return ENOMEM;
            }
            return 0;
         }
         
         virtual void destroy_i2c_drivers(void)
         {
            delete m_i2c_devs[0].driver;  
         }
         
         virtual int create_i2c_devices(void)
         {
            m_i2c_devs[0].conf.in_addr = 0x61;
            return 0;
         }
   
   };
   
};

#endif
